/*
  AntiRight
  (c) 2007 Jeffrey Bedard
  antiright@gmail.com

  This file is part of AntiRight.

  AntiRight is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  AntiRight is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with AntiRight; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
*/
#ifndef GSHTERM_H
#define GSHTERM_H

#include <gtkshell.h>
#include <vte/vte.h>
#include <unistd.h>

struct GSHTerm
{
	struct GSH *gsh;
	gchar *script;
	gchar *font;
	GtkWidget *widget;
};

#include "command_line.h"
#include "script.h"

void
gshterm_delete_tmp(gpointer data);

void
gshterm_exit_cb(GtkWidget *widget, gpointer data);

void
gshterm_set_terminal_options(GtkWidget *terminal);

GtkWidget *
gshterm_setup_terminal();

#endif

